@@ -1,9 +1,10 @@
 pub mod array;
 pub mod bit_util;
-pub mod buffer;
 pub mod builder;
 pub mod error;
+pub mod is_valid;
 pub mod kernels;
 pub mod prelude;
+pub mod trusted_len;
 pub mod utils;
 pub mod vec;
