@@ -25,7 +25,7 @@ impl<T: ArrowNativeType> Drop for AlignedVec<T> {
             let ptr: *mut T = me.as_mut_ptr();
             let ptr = ptr as *mut u8;
             let ptr = std::ptr::NonNull::new(ptr).unwrap();
-            unsafe { alloc::free_aligned::<u8>(ptr, self.capacity()) }
+            unsafe { alloc::free_aligned::<u8>(ptr, me.capacity() * mem::size_of::<T>()) }
         }
     }
 }
@@ -36,7 +36,7 @@ impl<T: ArrowNativeType> FromIterator<T> for AlignedVec<T> {
         let sh = iter.size_hint();
         let size = sh.1.unwrap_or(sh.0);
 
-        let mut av = Self::with_capacity_aligned(size);
+        let mut av = Self::with_capacity(size);
         av.extend(iter);
 
         // Iterator size hint wasn't correct and reallocation has occurred
@@ -49,7 +49,7 @@ impl<T: Copy + ArrowNativeType> AlignedVec<T> {
     /// Uses a memcpy to initialize this AlignedVec
     pub fn new_from_slice(other: &[T]) -> Self {
         let len = other.len();
-        let mut av = Self::with_capacity_aligned(len);
+        let mut av = Self::with_capacity(len);
         unsafe {
             // Safety:
             // we set initiate the memory after this with a memcpy.
@@ -81,7 +81,7 @@ impl<T: ArrowNativeType> AlignedVec<T> {
     /// by arrow spec.
     /// Read more:
     /// <https://github.com/rust-ndarray/ndarray/issues/771>
-    pub fn with_capacity_aligned(size: usize) -> Self {
+    pub fn with_capacity(size: usize) -> Self {
         // Can only have a zero copy to arrow memory if address of first byte % 64 == 0
         let t_size = std::mem::size_of::<T>();
         let capacity = size * t_size;
@@ -162,22 +162,27 @@ impl<T: ArrowNativeType> AlignedVec<T> {
     ///
     /// - `new_len` must be less than or equal to `capacity`.
     /// - The elements at `old_len..new_len` must be initialized.
+    #[inline]
     pub unsafe fn set_len(&mut self, new_len: usize) {
         self.inner.set_len(new_len);
     }
 
+    #[inline]
     pub fn as_ptr(&self) -> *const T {
         self.inner.as_ptr()
     }
 
+    #[inline]
     pub fn as_mut_ptr(&mut self) -> *mut T {
         self.inner.as_mut_ptr()
     }
 
+    #[inline]
     pub fn as_mut_slice(&mut self) -> &mut [T] {
         self.inner.as_mut_slice()
     }
 
+    #[inline]
     pub fn as_slice(&self) -> &[T] {
         self.inner.as_slice()
     }
@@ -207,16 +212,20 @@ impl<T: ArrowNativeType> AlignedVec<T> {
 
     /// Transform this array to an Arrow Buffer.
     pub fn into_arrow_buffer(self) -> Buffer {
-        let values = unsafe { self.into_inner() };
+        if self.is_empty() && self.capacity() == 0 {
+            MutableBuffer::new(0).into()
+        } else {
+            let values = unsafe { self.into_inner() };
 
-        let me = mem::ManuallyDrop::new(values);
-        let ptr = me.as_ptr() as *mut u8;
-        let len = me.len() * std::mem::size_of::<T>();
-        let capacity = me.capacity() * std::mem::size_of::<T>();
-        debug_assert_eq!((ptr as usize) % 64, 0);
-        let ptr = std::ptr::NonNull::new(ptr).unwrap();
+            let me = mem::ManuallyDrop::new(values);
+            let ptr = me.as_ptr() as *mut u8;
+            let len = me.len() * std::mem::size_of::<T>();
+            let capacity = me.capacity() * std::mem::size_of::<T>();
+            debug_assert_eq!((ptr as usize) % 64, 0);
+            let ptr = std::ptr::NonNull::new(ptr).unwrap();
 
-        unsafe { Buffer::from_raw_parts(ptr, len, capacity) }
+            unsafe { Buffer::from_raw_parts(ptr, len, capacity) }
+        }
     }
 
     pub fn into_primitive_array<A: ArrowPrimitiveType>(
@@ -296,12 +305,15 @@ impl<T: ArrowNativeType> Default for AlignedVec<T> {
     fn default() -> Self {
         // Be careful here. Don't initialize with a normal Vec as this will cause the wrong deallocator
         // to run and SIGSEGV
-        Self::with_capacity_aligned(0)
+        Self::with_capacity(0)
     }
 }
 
 impl<T: ArrowNativeType> FromTrustedLenIterator<T> for AlignedVec<T> {
-    fn from_iter_trusted_length<I: IntoIterator<Item = T> + TrustedLen>(iter: I) -> Self {
+    fn from_iter_trusted_length<I: IntoIterator<Item = T>>(iter: I) -> Self
+    where
+        I::IntoIter: TrustedLen,
+    {
         let iter = iter.into_iter();
         let len = iter.size_hint().0;
         // Safety:
@@ -323,7 +335,7 @@ mod test {
     fn test_aligned_vec_allocations() {
         // Can only have a zero copy to arrow memory if address of first byte % 64 == 0
         // check if we can increase above initial capacity and keep the Arrow alignment
-        let mut v = AlignedVec::with_capacity_aligned(2);
+        let mut v = AlignedVec::with_capacity(2);
         v.push(1);
         v.push(2);
         v.push(3);
@@ -333,7 +345,7 @@ mod test {
         assert_eq!((ptr as usize) % alloc::ALIGNMENT, 0);
 
         // check if we can shrink to fit
-        let mut v = AlignedVec::with_capacity_aligned(10);
+        let mut v = AlignedVec::with_capacity(10);
         v.push(1);
         v.push(2);
         v.shrink_to_fit();
